==> agentcomlink-0.1.6.tar.gz: agentcomlink-0.1.6/agentcomlink/files.py <==
import os

from agentcomlink.constants import storage_path


def check_files():
    if not os.path.exists(storage_path):
        os.makedirs(storage_path, exist_ok=True)

def get_storage_path():
    return storage_path

def set_storage_path(new_path):
    global storage_path
    if os.path.exists(new_path):  # Check if the new_path exists
        storage_path = new_path
        return True
    else:
        return False  # The new path doesn't exist


def add_file(path, content):
    check_files()
    with open(os.path.join(storage_path, path), "w") as f:
        f.write(content)
    return True


def remove_file(path):
    check_files()
    os.remove(os.path.join(storage_path, path))  # Removes the file
    return True


def update_file(path, content):
    check_files()
    with open(os.path.join(storage_path, path), "a") as f:  # 'a' for appending
        f.write(content)
    return True


def list_files(path="."):
    check_files()
    return os.listdir(os.path.join(storage_path, path))  # Returns the list of files

def list_files_formatted(path="."):
    check_files()
    files = os.listdir(os.path.join(storage_path, path))
    files_formatted = []
    for file in files:
        if os.path.isdir(os.path.join(storage_path, path, file)):
            files_formatted.append(file + "/")
        else:
            files_formatted.append(file)
    return "User's Files:\n" + "\n".join(files_formatted)

def get_file(path):
    check_files()
    with open(os.path.join(storage_path, path), "r") as f:  # 'r' for reading
        content = f.read()
    return content

==> agentcomlink-0.1.7.tar.gz: agentcomlink-0.1.7/agentcomlink/files.py <==
import os

from agentcomlink.constants import storage_path


def check_files():
    if not os.path.exists(storage_path):
        os.makedirs(storage_path, exist_ok=True)

def get_storage_path():
    return storage_path

def set_storage_path(new_path):
    global storage_path
    if os.path.exists(new_path):  # Check if the new_path exists
        storage_path = new_path
        return True
    else:
        return False  # The new path doesn't exist


def add_file(path, content):
    check_files()
    with open(os.path.join(storage_path, path), "w") as f:
        f.write(content)
    return True


def remove_file(path):
    check_files()
    os.remove(os.path.join(storage_path, path))  # Removes the file
    return True


def update_file(path, content):
    check_files()
    with open(os.path.join(storage_path, path), "a") as f:  # 'a' for appending
        f.write(content)
    return True


def list_files(path="."):
    check_files()
    return os.listdir(os.path.join(storage_path, path))  # Returns the list of files

def list_files_formatted(path="."):
    check_files()
    files = os.listdir(os.path.join(storage_path, path))
    files_formatted = []
    for file in files:
        if os.path.isdir(os.path.join(storage_path, path, file)):
            files_formatted.append(os.path.join(storage_path, file + "/"))
        else:
            files_formatted.append(os.path.join(storage_path, file))
    return "User's Files:\n" + "\n".join(files_formatted)

def get_file(path):
    check_files()
    with open(os.path.join(storage_path, path), "r") as f:  # 'r' for reading
        content = f.read()
    return content
